@@ -1,5 +1,8 @@
 package Slovo::Model::Domove;
 use Mojo::Base -base, -signatures;
+use feature qw(lexical_subs unicode_strings);
+## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+no warnings "experimental::lexical_subs";
 
 has 'dbx';
 
