@@ -5,6 +5,9 @@ BEGIN {
   binmode STDERR => ':utf8';
 }
 use Mojo::Base -role, -signatures;
+use feature qw(lexical_subs unicode_strings);
+## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+no warnings "experimental::lexical_subs";
 use Test::More;
 use Mojo::File qw(path tempdir);
 use Mojo::ByteStream 'b';
